#ifndef GROUPMETA_H		// -*- c++ -*-
#define GROUPMETA_H
///
// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
///
#include "metabase.h"

class FileContext;

class GroupMeta : public MetaBase {
public:
  Pagent* load(const xmlpp::Element& node, Group* parent,
	       const FileContext &context);
  
  Viewent::Ref create_viewent(View& view, Pagent& node);
  
  PropBase* getProp();
};

#endif
